Learn R Programming

akc (version 0.9.4)

akc-package: akc: Automatic Knowledge Classification

Description

logo

A tidy framework for automatic knowledge classification and visualization. Currently, the core functionality of the framework is mainly supported by modularity-based clustering (community detection) in keyword co-occurrence network, and focuses on co-word analysis of bibliometric research. However, the designed functions in 'akc' are general, and could be extended to solve other tasks in text mining as well.

Arguments

See Also

Useful links: